package statistic

import (
	"kpt-tmr-group/http/middleware"
	"kpt-tmr-group/pkg/apierr"
	"kpt-tmr-group/pkg/ginutil"
	"kpt-tmr-group/pkg/valid"
	operationPb "kpt-tmr-group/proto/go/backend/operation"
	"net/http"

	"github.com/gin-gonic/gin"
)

// SearchFormulaEstimateList 配方评估
func SearchFormulaEstimateList(c *gin.Context) {
	var req operationPb.SearchFormulaEstimateRequest
	if err := ginutil.BindProto(c, &req); err != nil {
		apierr.AbortBadRequest(c, http.StatusBadRequest, err)
		return
	}

	if err := valid.ValidateStruct(&req,
		valid.Field(&req.Name, valid.Required),
		valid.Field(&req.StartTime, valid.Required),
		valid.Field(&req.EndTime, valid.Required),
		valid.Field(&req.SearchType, valid.Required, valid.Min(0), valid.Max(2)),
	); err != nil {
		apierr.AbortBadRequest(c, http.StatusBadRequest, err)
		return
	}

	req.Pagination = &operationPb.PaginationModel{
		Page:       int32(c.GetInt(middleware.Page)),
		PageSize:   int32(c.GetInt(middleware.PageSize)),
		PageOffset: int32(c.GetInt(middleware.PageOffset)),
	}

	res, err := middleware.BackendOperation(c).OpsService.SearchFormulaEstimateList(c, &req)
	if err != nil {
		apierr.ClassifiedAbort(c, err)
		return
	}
	// ginutil.JSONResp(c, res)
	c.JSON(http.StatusOK, res)
}

// AnalysisAccuracy 准备性分析
func AnalysisAccuracy(c *gin.Context) {
	var req operationPb.SearchAnalysisAccuracyRequest
	if err := c.BindJSON(&req); err != nil {
		apierr.AbortBadRequest(c, http.StatusBadRequest, err)
		return
	}

	if err := valid.ValidateStruct(&req,
		valid.Field(&req.PastureIds, valid.Required),
		valid.Field(&req.CattleParentCategoryId, valid.Required),
	); err != nil {
		apierr.AbortBadRequest(c, http.StatusBadRequest, err)
		return
	}

	res, err := middleware.BackendOperation(c).OpsService.SearchAnalysisAccuracy(c, &req)
	if err != nil {
		apierr.ClassifiedAbort(c, err)
		return
	}
	c.JSON(http.StatusOK, res)
	//ginutil.JSONResp(c, res)
}
